/*---------------------------------------------------------------------------------------------------------*/
/* Copyright(c) 2011 Nuvoton Technology Corp. All rights reserved.                                         */
/*---------------------------------------------------------------------------------------------------------*/

/****************************************************************************************
  Nuvoton Technoledge Corp creadted by CA11 
  This demo code is used to show the GPIO function 
  P0/1/2/3/4/5 will output Hi-Lo.....       
***************************************************************************************/
#include "Common.h"

#define P0_MODE     0x5555
#define P1_MODE     0x5555
#define P2_MODE     0x5555
#define P3_MODE	    0x5555
#define P4_MODE     0x5555
#define P5_MODE	    0x5555

void TMR0_Delay1ms(uint32_t ulCNT);
void Timer0_Init(void);

/*en************************************************************************************
  Parameter:      	ulCNT:	delay time, unit is millisecond.                                     
  Description:   	Timer0 used for a delay function.                                    
****************************************************************************************/
void TMR0_Delay1ms(uint32_t ulCNT)
{
    TCMPR0 = 12000;                                        //12MHz/12000 = 1Khz
    TCSR0 |= CEN | TMR_IE;                                 // activate timer0 and enable timer0 interrupt   
    while (ulCNT != 1)
    {
        while((TISR0&TMR_TIF) != TMR_TIF);                 // Timer0 expire ?    
        TISR0 |= TMR_TIF;                                  // clear flag TIF   
        ulCNT--;
    }
    TCSR0 &= ~CEN;                                         // stop Tmier0   
}

/****************************************************************************************
  Description:                	Initialize timer0, period mode.                                    
****************************************************************************************/
void Timer0_Init()
{
    APBCLK |= TMR0_CLKEN;                                  //Enable APB CLK   
    CLKSEL1 = CLKSEL1 & (~TM0_CLK) | TM0_12M_32K;          //Select external crystal as timer module clock   
    TCSR0  |= CRST;                                        //Reset Timer0   
    TCSR0  &= 0xFFFFFF00 ;                                 //CLK no division   
    TCSR0   = TCSR0 & (~TMR_MODE) | MODE_PERIOD;           // Period mode   
}

main(void)
{
    Un_Lock_Reg();                                         //Unlock protected register bits for user to access   
    PWRCON = PWRCON & (~XTLCLK_EN) | XTAL12M_EN;           // Enable EXT osc   
    while((CLKSTATUS & XTL_STB) == 0); 	                   // Wait 12M osc stable   
    CLKSEL0 = (CLKSEL0 & (~HCLK)) | HCLK_12M_32K;          //Select 12M as system CLK   
    Lock_Reg();                                            //Lock protected register bits again   

    P0_PMD = P0_MODE;                                      //Configure all pins of P0 port as output mode   
    P1_PMD = P1_MODE;                                      //Configure all pins of P1 port as output mode   
    P2_PMD = P2_MODE;                                      //Configure all pins of P2 port as output mode   
    P3_PMD = P3_MODE;                                      //Configure all pins of P3 port as output mode   
    P4_PMD = P4_MODE;                                      //Configure all pins of P4 port as output mode   
    P5_PMD = P5_MODE;                                      //Configure all pins of P5 port as output mode   
    
    Timer0_Init();

    while(1) 
    {
        P0_DOUT = 0x00;                                    //output low level to all pins of P0 port   
        P1_DOUT = 0x00;                                    //output low level to all pins of P1 port   
        P2_DOUT = 0x00;                                    //output low level to all pins of P2 port   
        P3_DOUT = 0x00;                                    //output low level to all pins of P3 port   
        P4_DOUT = 0x00;                                    //output low level to all pins of P4 port   
        P5_DOUT = 0x00;                                    //output low level to all pins of P5 port   
        TMR0_Delay1ms(50);
        
        P0_DOUT = 0xFF;                                    //output high level to all pins of P0 port   
        P1_DOUT = 0xFF;                                    //output high level to all pins of P1 port   
        P2_DOUT = 0xFF;                                    //output high level to all pins of P2 port   
        P3_DOUT = 0xFF;                                    //output high level to all pins of P3 port   
        P4_DOUT = 0xFF;                                    //output high level to all pins of P4 port   
        P5_DOUT = 0xFF;                                    //output high level to all pins of P5 port   
        TMR0_Delay1ms(50);
    }
}
